@@ -22,58 +22,39 @@
  */
 
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
+#include <config.h>
 #include <gtk/gtk.h>
-
-/* #include <stdlib.h> */
-#include "transfer.h"
-#include "table.h"
 #include "gst.h"
-#include "gst-report-hook.h"
+
+#include "table.h"
+#include "service-settings-table.h"
 #include "callbacks.h"
 
 GstTool *tool;
 
 static GstDialogSignal signals [] = {
-	{ "settings_button",         "clicked",       G_CALLBACK (on_settings_button_clicked)   },
-	{ "dialog_service_priority", "value-changed", G_CALLBACK (on_service_priority_changed)  },
-	{ "sequence_ordering",       "clicked",       G_CALLBACK (on_sequence_ordering_changed) },
-	{ "runlevels_menu",          "changed",       G_CALLBACK (on_runlevel_changed)          },
+	{ "services_list",          "button_press_event",     G_CALLBACK (on_table_button_press_event) },
+	{ "services_list",          "popup_menu",             G_CALLBACK (on_table_popup_menu) },
 	{ NULL }
 };
 
 static GstWidgetPolicy policies [] = {
-	/* Name                     Basic                        Advanced                   Root   User */
-	{ "settings_button",        GST_WIDGET_MODE_HIDDEN,      GST_WIDGET_MODE_SENSITIVE, TRUE,  FALSE },
-	{ "runlevels_menu",         GST_WIDGET_MODE_HIDDEN,      GST_WIDGET_MODE_SENSITIVE, TRUE,  TRUE  },
-	{ "sequence_ordering",      GST_WIDGET_MODE_HIDDEN,      GST_WIDGET_MODE_HIDDEN,    TRUE,  TRUE  },
-	{NULL}
+	{ NULL }
 };
 
 int 
 main (int argc, char *argv[])
 {
-	gst_init ("services-admin", argc, argv, NULL);
-	
-	tool = gst_tool_new();
-	gst_tool_construct (tool, "services", _("Services Settings"));
-	table_create ();
+	gst_init_tool ("services-admin", argc, argv, NULL);
+	tool = gst_services_tool_new ();
 
 	gst_dialog_set_widget_policies (tool->main_dialog, policies);
-	gst_tool_set_xml_funcs (tool, transfer_xml_to_gui, NULL, NULL);
-
 	gst_dialog_connect_signals (tool->main_dialog, signals);
-	g_signal_connect (G_OBJECT (tool->main_dialog),
-			  "complexity_change",
-			  G_CALLBACK (on_dialog_complexity_change),
-			  tool);
+	table_create ();
+	service_settings_table_create ();
 
-	gst_dialog_enable_complexity (tool->main_dialog);
+	gtk_widget_show (GTK_WIDGET (tool->main_dialog));
+	gtk_main ();
 
-	gst_tool_main (tool,FALSE);
-	
 	return 0;
 }
