@@ -30,8 +30,9 @@ enum {
 	COL_ACTIVE,
 	COL_DESC,
 	COL_IMAGE,
-	COL_POINTER,
 	COL_DANGEROUS,
+	COL_OBJECT,
+	COL_ITER,
 	COL_LAST
 };
 
